@@ -34,6 +34,8 @@ static const char description[] = I18N_NOOP("Kolor Lines - a little game about b
 
 int main( int argc, char **argv )
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
     Kdelibs4ConfigMigrator migrate(QStringLiteral("klines"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("klinesrc"));
